@@ -4,12 +4,18 @@ use std::num::ParseFloatError;
 use std::result;
 use thiserror::Error;
 
+#[cfg(feature = "datafusion-proto")]
+use datafusion_proto::logical_plan::to_proto::Error as DataFusionProtoError;
+
 #[cfg(feature = "pyo3")]
 use pyo3::{exceptions::PyValueError, PyErr};
 
 #[cfg(feature = "jni")]
 use jni::errors::Error as JniError;
 
+#[cfg(feature = "base64")]
+use base64::DecodeError as Base64DecodeError;
+
 pub type Result<T> = result::Result<T, VegaFusionError>;
 
 #[derive(Clone, Debug, Default)]
@@ -58,6 +64,10 @@ pub enum VegaFusionError {
     #[error("DataFusion error: {0}\n{1}")]
     DataFusionError(DataFusionError, ErrorContext),
 
+    #[cfg(feature = "datafusion-proto")]
+    #[error("DataFusion proto error: {0}\n{1}")]
+    DataFusionProtoError(DataFusionProtoError, ErrorContext),
+
     #[error("IO Error: {0}\n{1}")]
     IOError(std::io::Error, ErrorContext),
 
@@ -76,6 +86,10 @@ pub enum VegaFusionError {
     #[cfg(feature = "jni")]
     #[error("JNI Error: {0}\n{1}")]
     JniError(JniError, ErrorContext),
+
+    #[cfg(feature = "base64")]
+    #[error("Base64 Decode Error: {0}\n{1}")]
+    Base64DecodeError(Base64DecodeError, ErrorContext),
 }
 
 impl VegaFusionError {
@@ -127,6 +141,11 @@ impl VegaFusionError {
                 context.contexts.push(context_fn().into());
                 VegaFusionError::DataFusionError(err, context)
             }
+            #[cfg(feature = "datafusion-proto")]
+            DataFusionProtoError(err, mut context) => {
+                context.contexts.push(context_fn().into());
+                VegaFusionError::DataFusionProtoError(err, context)
+            }
             IOError(err, mut context) => {
                 context.contexts.push(context_fn().into());
                 VegaFusionError::IOError(err, context)
@@ -151,6 +170,11 @@ impl VegaFusionError {
                 context.contexts.push(context_fn().into());
                 VegaFusionError::JniError(err, context)
             }
+            #[cfg(feature = "base64")]
+            Base64DecodeError(err, mut context) => {
+                context.contexts.push(context_fn().into());
+                VegaFusionError::Base64DecodeError(err, context)
+            }
         }
     }
 
@@ -213,6 +237,10 @@ impl VegaFusionError {
             DataFusionError(err, context) => {
                 VegaFusionError::ExternalError(err.to_string(), context.clone())
             }
+            #[cfg(feature = "datafusion-proto")]
+            DataFusionProtoError(err, context) => {
+                VegaFusionError::ExternalError(err.to_string(), context.clone())
+            }
             IOError(err, context) => {
                 VegaFusionError::ExternalError(err.to_string(), context.clone())
             }
@@ -232,6 +260,10 @@ impl VegaFusionError {
             JniError(err, context) => {
                 VegaFusionError::ExternalError(err.to_string(), context.clone())
             }
+            #[cfg(feature = "base64")]
+            Base64DecodeError(err, context) => {
+                VegaFusionError::Base64DecodeError(err.clone(), context.clone())
+            }
         }
     }
 }
@@ -287,6 +319,13 @@ impl From<DataFusionError> for VegaFusionError {
     }
 }
 
+#[cfg(feature = "datafusion-proto")]
+impl From<DataFusionProtoError> for VegaFusionError {
+    fn from(err: DataFusionProtoError) -> Self {
+        Self::DataFusionProtoError(err, Default::default())
+    }
+}
+
 impl From<std::fmt::Error> for VegaFusionError {
     fn from(err: std::fmt::Error) -> Self {
         Self::FormatError(err, Default::default())
@@ -333,6 +372,13 @@ impl From<JniError> for VegaFusionError {
     }
 }
 
+#[cfg(feature = "base64")]
+impl From<Base64DecodeError> for VegaFusionError {
+    fn from(err: Base64DecodeError) -> Self {
+        Self::Base64DecodeError(err, Default::default())
+    }
+}
+
 pub trait ToExternalError<T> {
     fn external<S: Into<String>>(self, context: S) -> Result<T>;
 }
